aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-dccp.c
diff options
context:
space:
mode:
authorBill Meier <wmeier@newsguy.com>2008-12-18 19:08:49 +0000
committerBill Meier <wmeier@newsguy.com>2008-12-18 19:08:49 +0000
commitc544c209561e2661d014eac1b3f7a2a6a67af636 (patch)
treeada9aa2c01f7b2a0d24b67b54d2b571f6f4a0f85 /epan/dissectors/packet-dccp.c
parentdbd150e9484c48e8dbe71f5042d8b7cc8a4eea93 (diff)
Fix various typos and spelling errors (mostly in text strings)
svn path=/trunk/; revision=27050
Diffstat (limited to 'epan/dissectors/packet-dccp.c')
-rw-r--r--epan/dissectors/packet-dccp.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/epan/dissectors/packet-dccp.c b/epan/dissectors/packet-dccp.c
index 908b1c7670..89432f19a9 100644
--- a/epan/dissectors/packet-dccp.c
+++ b/epan/dissectors/packet-dccp.c
@@ -70,7 +70,7 @@
/* Some definitions and the dissect_options() logic have been taken from Arnaldo Carvalho de Melo's DCCP implementation, thanks! */
-#define DCCP_HDR_LEN 16 /* base DCCP header length, with 48 bits seqnos */
+#define DCCP_HDR_LEN 16 /* base DCCP header length, with 48 bits seqnums */
#define DCCP_HDR_LEN_MIN 12 /* , with 24 bits seqnum */
#define DCCP_HDR_PKT_TYPES_LEN_MAX 12 /* max per packet type extra header length */
#define DCCP_OPT_LEN_MAX 1008
@@ -124,7 +124,7 @@ static const value_string dccp_feature_options_vals[] = {
static const value_string dccp_feature_numbers_vals[] = {
{0x01, "CCID"},
- {0x02, "Allow Short Seqnos"},
+ {0x02, "Allow Short Seqnums"},
{0x03, "Sequence Window"},
{0x04, "ECN Incapable"},
{0x05, "Ack Ratio"},
@@ -311,7 +311,7 @@ static void dissect_feature_options(proto_tree *dccp_options_tree, tvbuff_t *tvb
switch (feature_number) {
/* Server Priority features (RFC 4340, 6.3.1) */
case 1: /* Congestion Control ID (CCID); fall through */
- case 2: /* Allow Short Seqnos; fall through */
+ case 2: /* Allow Short Seqnums; fall through */
case 4: /* ECN Incapable; fall through */
case 6: /* Send Ack Vector; fall through */
case 7: /* Send NDP Count; fall through */